==> php7.4_7.4.33.orig.tar.xz: php-7.4.33/ext/json/json_parser.tab.h <==
/* A Bison parser, made by GNU Bison 3.0.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
# define YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef PHP_JSON_YYDEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define PHP_JSON_YYDEBUG 1
#  else
#   define PHP_JSON_YYDEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define PHP_JSON_YYDEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined PHP_JSON_YYDEBUG */
#if PHP_JSON_YYDEBUG
extern int php_json_yydebug;
#endif

/* Token type.  */
#ifndef PHP_JSON_YYTOKENTYPE
# define PHP_JSON_YYTOKENTYPE
  enum php_json_yytokentype
  {
    PHP_JSON_T_NUL = 258,
    PHP_JSON_T_TRUE = 259,
    PHP_JSON_T_FALSE = 260,
    PHP_JSON_T_INT = 261,
    PHP_JSON_T_DOUBLE = 262,
    PHP_JSON_T_STRING = 263,
    PHP_JSON_T_ESTRING = 264,
    PHP_JSON_T_EOI = 265,
    PHP_JSON_T_ERROR = 266
  };
#endif

/* Value type.  */
#if ! defined PHP_JSON_YYSTYPE && ! defined PHP_JSON_YYSTYPE_IS_DECLARED
typedef union PHP_JSON_YYSTYPE PHP_JSON_YYSTYPE;
union PHP_JSON_YYSTYPE
{


	zval value;
	struct {
		zend_string *key;
		zval val;
	} pair;


};
# define PHP_JSON_YYSTYPE_IS_TRIVIAL 1
# define PHP_JSON_YYSTYPE_IS_DECLARED 1
#endif



int php_json_yyparse (php_json_parser *parser);

#endif /* !YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED  */

==> php-8.2.7.tar.xz: php-8.2.7/ext/json/json_parser.tab.h <==
/* A Bison parser, made by GNU Bison 3.7.5.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
# define YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef PHP_JSON_YYDEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define PHP_JSON_YYDEBUG 1
#  else
#   define PHP_JSON_YYDEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define PHP_JSON_YYDEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined PHP_JSON_YYDEBUG */
#if PHP_JSON_YYDEBUG
extern int php_json_yydebug;
#endif

/* Token kinds.  */
#ifndef PHP_JSON_YYTOKENTYPE
# define PHP_JSON_YYTOKENTYPE
  enum php_json_yytokentype
  {
    PHP_JSON_YYEMPTY = -2,
    PHP_JSON_YYEOF = 0,            /* "end of file"  */
    PHP_JSON_YYerror = 256,        /* error  */
    PHP_JSON_YYUNDEF = 257,        /* "invalid token"  */
    PHP_JSON_T_NUL = 258,          /* PHP_JSON_T_NUL  */
    PHP_JSON_T_TRUE = 259,         /* PHP_JSON_T_TRUE  */
    PHP_JSON_T_FALSE = 260,        /* PHP_JSON_T_FALSE  */
    PHP_JSON_T_INT = 261,          /* PHP_JSON_T_INT  */
    PHP_JSON_T_DOUBLE = 262,       /* PHP_JSON_T_DOUBLE  */
    PHP_JSON_T_STRING = 263,       /* PHP_JSON_T_STRING  */
    PHP_JSON_T_ESTRING = 264,      /* PHP_JSON_T_ESTRING  */
    PHP_JSON_T_EOI = 265,          /* PHP_JSON_T_EOI  */
    PHP_JSON_T_ERROR = 266         /* PHP_JSON_T_ERROR  */
  };
  typedef enum php_json_yytokentype php_json_yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined PHP_JSON_YYSTYPE && ! defined PHP_JSON_YYSTYPE_IS_DECLARED
union PHP_JSON_YYSTYPE
{

	zval value;


};
typedef union PHP_JSON_YYSTYPE PHP_JSON_YYSTYPE;
# define PHP_JSON_YYSTYPE_IS_TRIVIAL 1
# define PHP_JSON_YYSTYPE_IS_DECLARED 1
#endif



int php_json_yyparse (php_json_parser *parser);

#endif /* !YY_PHP_JSON_YY_EXT_JSON_JSON_PARSER_TAB_H_INCLUDED  */
